BrickView<T> class
A responsive brick-style image grid widget. Displays images in layout similar to Google Images Supports custom gaps, padding, max height, and tap callbacks
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- BrickView
Constructors
-
BrickView({Key? key, required List<
String> ? imageUrls, double horizontalGap = 4.0, double verticalGap = 4.0, EdgeInsets padding = const EdgeInsets.all(10.0), double maxHeight = 150.0, void onImageTap(int index)?, double borderRadius = 6.0, Widget? loadingWidget, Widget? errorWidget, ScrollPhysics? physics}) -
const
Properties
- borderRadius → double
-
Corner radius for each image.
final
- errorWidget → Widget?
-
Widget displayed if an image fails to load.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- horizontalGap → double
-
Horizontal space between images in a same row.
final
-
imageUrls
→ List<
String> ? -
List of image urls to display.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- loadingWidget → Widget?
-
Widget displayed while an image is loading.
final
- maxHeight → double
-
Maximum height for each iamge
final
- onImageTap → void Function(int index)?
-
Callback when an image is tapped.
final
- padding → EdgeInsets
-
Outer padding for the whole grid.
final
- physics → ScrollPhysics?
-
Scroll physics for the outer ListView
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- verticalGap → double
-
Vertical space between rows of images.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited